========================
Content of doc directory
========================

This directory contains everything that is related to documentation and
bureaucracy. You can find here 4 subdirectories:


feature_request
~~~~~~~~~~~~~~~

If some use case is not covered by Rally, it is the right place to request it.
To request new feature you should just explain use case on high level.
Technical details and writing code are not required at all.


samples
~~~~~~~

If you are looking for samples of deployments and benchmarks configuration
you are on the right way


source
~~~~~~

Source of documentation. Latest version of documentation_.

.. _documentation: http://rally.readthedocs.org/


user_stories
~~~~~~~~~~~~

Place where you can share any of Rally user experience. E.g. fixing some bugs,
measuring performance of different architectures or comparing different
hardware and so on..
